==> istio-model-v1beta1-6.7.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/GatewaySpecBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class GatewaySpecBuilder extends GatewaySpecFluentImpl<GatewaySpecBuilder> implements VisitableBuilder<GatewaySpec,GatewaySpecBuilder>{
  public GatewaySpecBuilder() {
    this(false);
  }
  public GatewaySpecBuilder(Boolean validationEnabled) {
    this(new GatewaySpec(), validationEnabled);
  }
  public GatewaySpecBuilder(GatewaySpecFluent<?> fluent) {
    this(fluent, false);
  }
  public GatewaySpecBuilder(GatewaySpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new GatewaySpec(), validationEnabled);
  }
  public GatewaySpecBuilder(GatewaySpecFluent<?> fluent,GatewaySpec instance) {
    this(fluent, instance, false);
  }
  public GatewaySpecBuilder(GatewaySpecFluent<?> fluent,GatewaySpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withSelector(instance.getSelector());
      fluent.withServers(instance.getServers());
    }
    this.validationEnabled = validationEnabled; 
  }
  public GatewaySpecBuilder(GatewaySpec instance) {
    this(instance,false);
  }
  public GatewaySpecBuilder(GatewaySpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withSelector(instance.getSelector());
      this.withServers(instance.getServers());
    }
    this.validationEnabled = validationEnabled; 
  }
  GatewaySpecFluent<?> fluent;
  Boolean validationEnabled;
  public GatewaySpec build() {
    GatewaySpec buildable = new GatewaySpec(fluent.getSelector(),fluent.getServers());
    return buildable;
  }
  
}

==> istio-model-v1beta1-6.8.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/GatewaySpecBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class GatewaySpecBuilder extends GatewaySpecFluent<GatewaySpecBuilder> implements VisitableBuilder<GatewaySpec,GatewaySpecBuilder>{
  public GatewaySpecBuilder() {
    this(false);
  }
  public GatewaySpecBuilder(Boolean validationEnabled) {
    this(new GatewaySpec(), validationEnabled);
  }
  public GatewaySpecBuilder(GatewaySpecFluent<?> fluent) {
    this(fluent, false);
  }
  public GatewaySpecBuilder(GatewaySpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new GatewaySpec(), validationEnabled);
  }
  public GatewaySpecBuilder(GatewaySpecFluent<?> fluent,GatewaySpec instance) {
    this(fluent, instance, false);
  }
  public GatewaySpecBuilder(GatewaySpecFluent<?> fluent,GatewaySpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new GatewaySpec());

    if (instance != null) {
      fluent.withSelector(instance.getSelector());
      fluent.withServers(instance.getServers());
      fluent.withSelector(instance.getSelector());
      fluent.withServers(instance.getServers());
    }
    this.validationEnabled = validationEnabled; 
  }
  public GatewaySpecBuilder(GatewaySpec instance) {
    this(instance,false);
  }
  public GatewaySpecBuilder(GatewaySpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new GatewaySpec());

    if (instance != null) {
      this.withSelector(instance.getSelector());
      this.withServers(instance.getServers());
      this.withSelector(instance.getSelector());
      this.withServers(instance.getServers());
    }
    this.validationEnabled = validationEnabled; 
  }
  GatewaySpecFluent<?> fluent;
  Boolean validationEnabled;
  public GatewaySpec build() {
    GatewaySpec buildable = new GatewaySpec(fluent.getSelector(),fluent.buildServers());
    return buildable;
  }
  
}
